==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowsLeftRightToLine.md <==
# ArrowsLeftRightToLine


```text
fontawesome-6/Solid/ArrowsLeftRightToLine
```

```text
include('fontawesome-6/Solid/ArrowsLeftRightToLine')
```



| Illustration | ArrowsLeftRightToLine |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowsLeftRightToLine.png) | ![illustration for ArrowsLeftRightToLine](../../fontawesome-6/Solid/ArrowsLeftRightToLine.Local.png) |




## ArrowsLeftRightToLine

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsLeftRightToLine
include('fontawesome-6/Solid/ArrowsLeftRightToLine')

' renders the element
ArrowsLeftRightToLine('ArrowsLeftRightToLine', 'Arrows Left Right To Line', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsLeftRightToLine
include('fontawesome-6/Solid/ArrowsLeftRightToLine')

' renders the element
ArrowsLeftRightToLine('ArrowsLeftRightToLine', 'Arrows Left Right To Line', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowsLeftRightToLine.md <==
# ArrowsLeftRightToLine


```text
fontawesome-6/Solid/ArrowsLeftRightToLine
```

```text
include('fontawesome-6/Solid/ArrowsLeftRightToLine')
```



| Illustration | ArrowsLeftRightToLine |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowsLeftRightToLine.png) | ![illustration for ArrowsLeftRightToLine](../../fontawesome-6/Solid/ArrowsLeftRightToLine.Local.png) |




## ArrowsLeftRightToLine

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsLeftRightToLine
include('fontawesome-6/Solid/ArrowsLeftRightToLine')

' renders the element
ArrowsLeftRightToLine('ArrowsLeftRightToLine', 'Arrows Left Right To Line', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsLeftRightToLine
include('fontawesome-6/Solid/ArrowsLeftRightToLine')

' renders the element
ArrowsLeftRightToLine('ArrowsLeftRightToLine', 'Arrows Left Right To Line', 'an optional tech label', 'an optional description')
@enduml
```
